@@ -25,7 +25,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 =head1 FUNCTIONS
 
@@ -89,7 +89,8 @@ sub all_repositories {
     };
 
     for (keys %$repos) {
-        $repos->{$_}->{dir} //= dir($_)->basename =~ s/\.git$//r
+        $repos->{$_}->{dir} //= dir($_)->basename =~ s/\.git$//r;
+        $repos->{$_}->{url} //= $_;
     }
 
     return $repos;
