@@ -8,6 +8,8 @@ use Cwd 'getcwd';
 
 use 5.014;
 
+our $VERSION = '0.03';
+
 =encoding utf8
 
 =head1 NAME
@@ -55,7 +57,8 @@ Run a command, in one of two ways:
 
 If the command is a CODE ref, it is run with this Repo object, and the entirety
 of C<%data>. The CODE reference should use normal print/say/warn/die behaviour.
-Its return value is discarded.
+Its return value is discarded. If the subref returns at all, it is considered to
+have succeeded.
 
 If it is an ARRAY ref, it is run with IO::Async::Process, with C<stdout> sent
 to the process's STDIN.
@@ -101,9 +104,11 @@ sub run {
     if (ref $command eq 'CODE') {
         loop->run_child(
             code => sub {
-                chdir $self->config->{dir};
-                $self->$command(%data)
+                $command->($self, %data); 0;
             },
+            setup => [
+                chdir => $self->config->{dir}
+            ],
             on_finish => sub {
                 my (undef, $exitcode, $stdout, $stderr) = @_;
                 $future->done(
@@ -117,27 +122,23 @@ sub run {
         );
     }
     else {
-        my ($stdout, $stderr);
-        loop->add(
-            IO::Async::Process->new(
-                code => sub {
-                    chdir $self->config->{dir};
-                    IPC::Run::run($command);
-                },
-                stdin => { from => $data{stdout} },
-                stdout => { into => \$stdout },
-                stderr => { into => \$stderr },
-                on_finish => sub {
-                    $future->done(
-                        stdout => $stdout, 
-                        stderr => $stderr, 
-                        exitcode => $_[0],
-                        past_stdout => $data{stdout},
-                        past_stderr => $data{stderr},
-                    );
-                }
-            )
-        );
+        loop->run_child(
+            command => $command,
+            setup => [
+                chdir => $self->config->{dir}
+            ],
+            stdin => $data{stdout},
+            on_finish => sub {
+                my (undef, $exitcode, $stdout, $stderr) = @_;
+                $future->done(
+                    stdout => $stdout, 
+                    stderr => $stderr, 
+                    exitcode => $exitcode,
+                    past_stdout => $data{stdout},
+                    past_stderr => $data{stderr},
+                );
+            }
+        )
     }
     return $future;
 }
